# -*- coding: utf-8 -
#
# Copyright (c) 2008, 2009 Benoit Chesneau <benoitc@e-engura.com> 
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#

from restclient.transport.base import HTTPResponse, HTTPTransportBase, USER_AGENT
from restclient.transport._httplib2 import HTTPLib2Transport, httplib2
from restclient.transport._curl import CurlTransport, pycurl

__all__ = [
    'HTTPResponse', 
    'HTTPTransportBase', 
    'USER_AGENT',
    'HTTPLib2Transport',
    'CurlTransport',
    'createHTTPTransport',
    'isCurl']


def createHTTPTransport(timeout=None):
    """Create default HTTP client instance
    prefers Curl to urllib"""
    if pycurl is not None:
        http = CurlTransport(timeout)
    elif httplib2 is not None:
        http = HTTPLib2Transport(timeout)
    else:
        raise RuntimeError("httplib2 or curl are missing")
    return http

def getDefaultHTTPTransport(timeout=None):
    """ Return the default http transport instance instance
    if no client has been set, it will create a default client.

    :param timeout: Default timeout value
    :return: the default client
    """
    return createHTTPTransport(timeout)

def isCurl(httptransport):
    """ Returns true if the given transport instance is CURL
    :param httptransport: Transport
    :return: true if transport is CURL
    """
    return isinstance(httptransport, CurlTransport)
